// Linear mixed effects, estimating unscaled random vector
DATA_SECTION
  init_int k
  init_int n
  init_vector x(1,n)
  init_matrix y(1,k,1,n)

PARAMETER_SECTION
  init_number beta0
  init_number beta1
  init_number logSigmaB(3)
  init_number logSigma
  random_effects_vector u(1,k,2)
  sdreport_number sigma
  sdreport_number sigmaB
  vector b(1,k)
  matrix yfit(1,k,1,n)
  number RSS
  objective_function_value f

PROCEDURE_SECTION
  sigma = mfexp(logSigma);
  sigmaB = mfexp(logSigmaB);
  b = u * sigmaB;
  for(int i=1; i<=k; i++)
    for(int j=1; j<=n; j++)
      yfit(i,j) = beta0 + b(i) + beta1*x(j);
  RSS = sum(square(y-yfit));
  f = 0.5*k*n*log(2.0*M_PI) + k*n*logSigma + RSS/(2.0*square(sigma));
  f += 0.5*k*log(2.0*M_PI) + sum(square(u))/2.0;

REPORT_SECTION
  report << "# f"      << endl << f      << endl << endl;
  report << "# beta0"  << endl << beta0  << endl << endl;
  report << "# beta1"  << endl << beta1  << endl << endl;
  report << "# b"      << endl << b      << endl << endl;
  report << "# sigmaB" << endl << sigmaB << endl << endl;
  report << "# sigma"  << endl << sigma  << endl << endl;
  report << "# x"      << endl << x      << endl << endl;
  report << "# y"      << endl << y      << endl << endl;
  report << "# yfit"   << endl << yfit   << endl << endl;
